<!--- 
	csw-split-carousel.cfc 
	
	Version: [2022-12-23 12:00 pm]
---> 


<cfcomponent displayname="csw-imagetextblock-rollover" output="false" hint="Image Textblock Rollover Functions" extends="_cs_widgets._common.csw-common">

	<cffunction name="loadResources" access="public" output="Yes" returntype="void">
		<cfscript>

			Server.CommonSpot.udf.resources.loadResources("JQuery");
			//Server.CommonSpot.udf.resources.loadResources("Bootstrap");
			Server.CommonSpot.udf.resources.loadResources("FontAwesome");
			Server.CommonSpot.udf.resources.loadResources("swiper");
			Server.CommonSpot.udf.resources.loadResources("cswCommonStyles");
			Server.CommonSpot.udf.resources.loadResources("cswButtonStyles");
			Server.CommonSpot.udf.resources.loadResources("cswTextStyles");
			Server.CommonSpot.udf.resources.loadResources("cswSplitCarousel");

			// If a custom stylesheet has been registered, go ahead and load it.
			if( StructKeyExists(Request.Site.CS_Resources.Resources_by_name,'cswCommonStyles_custom') )
				Server.CommonSpot.udf.resources.loadResources("cswCommonStyles_custom");
			if( StructKeyExists(Request.Site.CS_Resources.Resources_by_name,'cswButtonStyles_custom') )
				Server.CommonSpot.udf.resources.loadResources("cswButtonStyles_custom");
			if( StructKeyExists(Request.Site.CS_Resources.Resources_by_name,'cswTextStyles_custom') )
				Server.CommonSpot.udf.resources.loadResources("cswTextStyles_custom");			
			if ( StructKeyExists(Request.Site.CS_Resources.Resources_by_name,'cswSplitCarousel_custom') )
				Server.CommonSpot.udf.resources.loadResources("cswSplitCarousel_custom");

		</cfscript>
	</cffunction>
	
	

	<cffunction name="loadProperties" access="public" returntype="struct" output="Yes">
		<cfargument name="elementInfo" type="struct" required="Yes">
		<cfargument name="rhCaller" type="struct" required="false" default="#StructNew()#">
		<cfargument name="showDataError" type="boolean" required="false" default="true">
		
		<cfscript>
			var widgetMetadataFormName = "CSW Split Carousel";
			var props = StructNew();
			var rhMetadata = arguments.ElementInfo.RenderHandlerMetaData;
			var widgetData = StructNew();


			// Check for Props and Layout Binding
			if( NOT hasPropsLayoutBinding(ElementInfo=arguments.elementInfo,metadataFormName=widgetMetadataFormName,rhCaller=arguments.rhCaller) )
				return props;
			
			//
			// Get Metadata (Core Slider Menu metadata)
			// ----------------------------------------------
			widgetData = rhMetadata[widgetMetadataFormName];
			

			/*********************************/
			/**** CAROUSEL PROPERTIES TAB ****/
			/*********************************/

			// Options - optional
			props.options = getStandardField( widgetData=widgetData, field='options', defValue='showarrows,showdots,autoheight' );

			// Slider Wait Time - required
			props.slideWaitTime = getStandardField( widgetData=widgetData, field='SlideWaitTime', defValue='3000' );

			// Slide Transition Speed - required
			props.slideTransitionSpeed = getStandardField( widgetData=widgetData, field='SlideTransitionSpeed', defValue='1000' );

			// Slide Transition Effect - optional
			props.slideTransitionEffect = getStandardField( widgetData=widgetData, field='SlideTransitionEffect', defValue='slide' );


			// Pagination Style
			props.paginationStyle = getStandardField( widgetData=widgetData, field='Pagination_Style', defValue='bullets' );
	
			// Pagination Alignment
			props.paginationAlignment = getStandardField( widgetData=widgetData, field='Pagination_Alignment', defValue='bullets' );
			if( props.paginationStyle eq 'none' OR props.paginationStyle eq 'progressbar' )
				props.paginationAlignment = '';
			
			
			// -----------------------------------
			// General Properties
			// -----------------------------------

			// Element
			props.element = getFieldSettings(widgetData=widgetData, field='Overall', defShow='no', defBgColor='' );	

			// Background Image
			props.backgroundImage = getStandardMetadataImageField( widgetData=widgetData, field='Background_Image', defValue='' );		
			
			// Background Image Focal Point
			props.backgroundImageFocalPoint = getStandardField( widgetData=widgetData, field='Background_Image_Focal_Point', defValue='' );		

			// Text Padding
			props.defaultTextPadding = getStandardField( widgetData=widgetData, field='Text_Padding', defValue='' );		

			
			// -----------------------------------
			// Link/Button Properties
			// -----------------------------------

			// LinkLocation - optional
			props.linkLocation = getStandardField( widgetData=widgetData, field='LinkLocation', defValue='cswLinkBtnPos-undertext' );
			
			// Button Type
			props.buttonType = getStandardField( widgetData=widgetData, field='Button_Type', defValue='cswButton' );

			// Button (STRUCT)
			props.button = getFieldSettings(widgetData=widgetData, field='button', defShow='1', defAlign='cswTextAlign-inherit', defSize='cswSize-normal', defColor='white', defBgColor='black', defEffects='cswEffect-default', defStyle="");

			// LINK (STRUCT)
			props.link = getFieldSettings(widgetData=widgetData, field='link', defAlign='cswTextAlign-inherit', defSize='cswSize-normal', defColor='white', defPadding='');

			// Button Corners
			props.buttonCorners = getStandardField( widgetData=widgetData, field='Button_Corners', defValue='' );

			// Link/Button Text
			props.linkText = getStandardField( widgetData=widgetData, field='LinkText', defValue='' );

			// Icon
			props.buttonIcon = getStandardField( widgetData=widgetData, field='icon', defValue='' );

			return props;
		</cfscript>
	</cffunction>


	
	<cffunction name="getAndRenderItems" access="public" output="Yes" returntype="void">
		<cfargument name="elementDataStruct" type="struct" required="Yes">
		<cfargument name="elementParamsStruct" type="struct" required="Yes">
		<cfargument name="propsStruct" type="struct" required="Yes">

		<cfscript>
			var elementData = arguments.elementDataStruct;
			var eparams = arguments.elementParamsStruct;
			var props = arguments.propsStruct;
			var data = StructNew();

			// Set the element ID
			var elementID = request.element.id;
			var items = elementData.propertyValues;
			var numItems = arrayLen(items);

			// Init Carousel Options
			var showdots = false;
			var showarrows = false;
			var infiniteloop = false;
			var autoheight = false;
			var fixedHeightClass = '';
			var itm = 0;
			var i = 0;
			var styleAttr = '';
			var outerClasses = '';
		</cfscript>

		<cfif len(trim(props.options))>
			<cfloop index="itm" list="#props.options#">
				<cfscript>
					if (itm eq "showdots")
						showdots = true;
					if (itm eq "showarrows")
						showarrows = true;
					if (itm eq "autoheight")
						autoheight = true;
					if (itm eq "infiniteloop")
						infiniteloop = true;
					if (itm eq "fixedheight")
						fixedHeightClass = 'cswSwiperFixedHeight';
					if (itm eq "autoheight")
						autoHeight = true;
				</cfscript>
			</cfloop>
		</cfif>

		<cfset args = "'#elementID#',#infiniteloop#,#autoHeight#,#showArrows#,#showDots#,#props.slideWaitTime#,#props.SlideTransitionSpeed#,'#props.SlideTransitionEffect#','#props.paginationStyle#'">

		<!--- args is a CF variable being used within a JS statement, it needs the pound signs --->
		<cfsavecontent variable="cswCarouselJS">
			<cfoutput>
				jQuery(document).ready(function() {
					initSplitCarousel(#args#);
					jQuery(window).resize( doResize );
				});
			</cfoutput>
		</cfsavecontent>

		<cfscript>
			// Load custom javascript at the bottom of the page.
			Server.CommonSpot.udf.resources.addFooterJS(cswCarouselJS, 'TERTIARY');
			
			
			styleAttr = '';
			if( structKeyExists(props,'element') )
			{
				if( len(props.element.padding) )
					styleAttr = styleAttr & 'padding: #props.element.padding#;';
				if( len(props.element.bgColor) )
					styleAttr = styleAttr & 'background-color: #props.element.bgColor#;';
			}
			
			if( StructKeyExists(props,'backgroundImage') AND len(props.backgroundImage) )
				styleAttr = styleAttr & "background-image: url('#props.backgroundImage#'); background-repeat: no-repeat; background-size: cover;";
				
			if( len(styleAttr) )
				styleAttr = 'style="#styleAttr#"';
				
			if( StructKeyExists(props,'backgroundImageFocalPoint') )
				outerClasses = trim( outerClasses & ' #props.backgroundImageFocalPoint#');	
		
		</cfscript>

		<cfoutput>
			<!--- Slider main container --->
			<div class="cswSplitOuter #outerClasses#" #styleAttr#>
				<div id="cswSplit#elementID#" class="cswSplit swiper-container cswSwiperContainer #fixedHeightClass#" ##>
	
					<!--- Additional required wrapper --->
					<div class="swiper-wrapper cswWrapper">
					</cfoutput>
	
						<cfscript>
							//
							// Loop over each record and output a 'slide'
							//
							for( i=1; i lte numItems; i=i+1 )
							{
								// Get Data
								data = getItemData(items[i].values);
	
								// RENDER the Image Textblock Rollover container
								renderSlide( data, props );
							}
						</cfscript>
	
					<cfoutput></div></cfoutput>
	
					<cfif props.paginationStyle neq 'none'>
						<cfoutput><div class="swiper-pagination #props.paginationAlignment#"></div></cfoutput>
					</cfif>
	
					<cfif showarrows>
						<!--- If we need navigation buttons --->
						<cfoutput>
					 	<div class="swiper-button-next">&rsaquo;</div>
					 	<div class="swiper-button-prev">&lsaquo;</div>
						</cfoutput>
					</cfif>
					
				<cfoutput>	
				</div>
			</div>
		</cfoutput>

	</cffunction>

	
	

	<cffunction name="getItemData" access="public" output="Yes" returntype="struct">
		<cfargument name="valuesStruct" type="struct" required="Yes">

		<cfscript>
			var data = StructNew();
         var values = arguments.valuesStruct;

			// -----------------------------------
			// Slide Layout Properties
			// -----------------------------------			
			
			// SlideLayout 
			data.slideLayout = getStandardField( widgetData=values, field='slideLayout', defValue='csw50-50' );			
				
			// SlideBackgroundColor
			data.slideBackgroundColor = getFieldSettings(widgetData=values, field='slideBackgroundColor', defColor='white');
		 	if( len(data.slideBackgroundColor.color) EQ 0 )
    			data.slideBackgroundColor.color = 'white';				
							
			// -----------------------------------
			// Slide Image Properties
			// -----------------------------------			
			
			// SLIDE IMAGE URL
			// Assume slideImage field is server relative URL, but they might bind it to
			// the wrong thing so protect against that
			// 2 cases:
			// 	case 1: Bound to CSImage field, in which case it is a structure
			//	case 2: Bound to text field that is server relative URL
			if( StructKeyExists(values,'slideImage') )
			{
				data.ImgURL = values.slideImage;
				if( IsStruct(data.ImgURL) AND StructKeyExists(data.ImgURL,'ResolvedURL') )
					data.ImgURL = data.ImgURL.ResolvedURL.ServerRelative;
				else
					data.ImgURL = trim(data.ImgURL);
			}
			else
			{
				data.ImgURL = '';
			}

			// ImageLocation 
			data.ImageLocation = getStandardField( widgetData=values, field='ImageLocation', defValue='cswImageLeft' );

			// ImageSize - Optional
			data.bgSize = getStandardField( widgetData=values, field='ImageSize', defValue='cswBgSizeCover' );			

			// ImageFocalPoint - Optional
			data.bgPos = getStandardField( widgetData=values, field='ImageFocalPoint', defValue='cswBgPosCenter' );


			// -----------------------------------
			// Slide Text Properties - Optional
			// -----------------------------------

			// Text Style (STRUCT)
			data.textStyle = getFieldSettings(widgetData=values, field='TextStyle', defShow='0', defColor='', defPadding='');

			// Slide Text
			data.slidetext = getStandardField( widgetData=values, field='SlideText', defValue='' );

			// TextPosition - Optional
			data.textPosition = getStandardField( widgetData=values, field='textPosition', defValue='' );			

				
			// -----------------------------------
			// Button Properties
			// -----------------------------------				

			// Button Type				
			data.buttonType = getStandardField( widgetData=values, field='Button_Type', defValue='' );
			
			// Button (STRUCT)
			data.button = getFieldSettings(widgetData=values, field='button', defShow='', defAlign='', defSize='', defColor='', defBgColor='', defEffects='', defStyle='', defTag='', defFontSettings='');
			
			// LINK (STRUCT)
			data.link = getFieldSettings(widgetData=values, field='link', defShow='', defAlign='', defSize='', defColor='', defBgColor='', defEffects='', defStyle='', defTag='', defFontSettings='');
			
			// Button Corners
			data.buttonCorners = getStandardField( widgetData=values, field='Button_Corners', defValue='' );						
			
			// LinkURL - Optional
			data.linkURL = getStandardCustomElementLinkField(widgetData=values, field='LinkURL', defValue='');

			// Link Url Target
			data.LinkTarget = getStandardCustomElementLinkFieldTarget(widgetData=values, field='LinkURL', defValue='');

			// Link Url OnClick
			data.onClick = getStandardCustomElementLinkFieldOnClick(widgetData=values, field='LinkURL', defValue='');

			if( len(data.linkURL) )
			{
				if( len(trim(values.linkText)) )
					data.toLink = "textLink";
				else
					data.toLink = "imageLink";
			}
			else
				data.toLink = "";

			// Link/Button Text
			data.linkText = getStandardField( widgetData=values, field='LinkText', defValue='' );

			// Icon
			data.buttonIcon = getStandardField( widgetData=values, field='icon', defValue='' );

		</cfscript>

		<cfreturn data>

	</cffunction>
	
	

	<cffunction name="renderSlide" access="public" output="Yes" returntype="void">
		<cfargument name="dataStruct" required="Yes" type="struct">
		<cfargument name="propsStruct" required="Yes" type="struct">
		
		<cfscript>
			var data = arguments.dataStruct;
			var props = arguments.propsStruct;
			var style = '';
			var textStyleAttr = '';
			var slideStyleAttr = '';
			var uID = getTickCount();
			var currLinkURL = '';
			var currLinkText = props.linkText;
			var currButtonType = props.buttonType;
			var currButtonCorners = props.buttonCorners;
			var currButtonIcon = props.buttonIcon;
			var currButtonStruct = props.button;
			var currLinkStruct = props.link;
			var keys = 'align,padding,fontClasses,size,effect,style,color,bgColor';

			//
			// Check for slide settings in DATA
			//
			if( StructKeyExists(data,'linkURL') AND len(data.linkURL) )
				currLinkURL = data.linkURL;
			if( StructKeyExists(data,'linkText') AND len(data.linkText) )
				currLinkText = data.linkText;
			if( StructKeyExists(data,'buttonType') AND len(data.buttonType) )
				currButtonType = data.buttonType;
			if( StructKeyExists(data,'buttonCorners') AND len(data.buttonCorners) )
				currButtonCorners = data.buttonCorners;
			if( StructKeyExists(data,'buttonIcon') AND len(data.buttonIcon) )
				currButtonIcon = data.buttonIcon;			
			if( StructKeyExists(data,'button') )
				currButtonStruct = data.button;			
			if( StructKeyExists(data,'link') )
				currLinkStruct = data.link;			

			if( len(data.textStyle.color) )
				textStyleAttr = 'color:#data.textStyle.color#;';

			if( len(data.textStyle.padding) )
				textStyleAttr = textStyleAttr & 'padding:#data.textStyle.padding#;';
			else if( len(props.defaultTextPadding) )
				textStyleAttr = textStyleAttr & 'padding:#props.defaultTextPadding#;';	

			if( len(data.slideBackgroundColor.color) )
				slideStyleAttr = 'style="background-color:#data.slideBackgroundColor.color#;"';
		</cfscript>

		<cfoutput>
			<div class="swiper-slide #data.slideLayout# #data.imageLocation# cswSlide" #slideStyleAttr#>
				<section class="wrapper centered content-area cswSectionWrapper #data.textPosition#">

					<!--- render Image (always render first so on mobile its on top --->
					<cfif data.slideLayout neq 'csw0' AND data.ImgURL neq ''>
						<cfscript>
							style = "background-image:url('#data.ImgURL#');";
							if( data.toLink is "imageLink" )
								style = style & 'onclick="location.href=' & "'#currLinkURL#';";
						</cfscript>
						<div class="slider-image cswItem-#uID# cswSlide #data.bgSize# #data.bgPos#" style="#style#"></div>
					<cfelse>
						<div class="slider-image cswItem-#uID# cswSlide"></div>
					</cfif>

					<!--- Render text --->
				<div class="slider-text-wrapper">
						<div class="slider-text slide#uID# cswSlideText">
							<cfif len(data.slideText)>
								<div style="#textStyleAttr#">
									#data.slideText#
							</cfif>

								<!--- render link --->
								<cfif currLinkURL neq ''
										AND currLinkText neq ''
										AND FindNoCase('undertext', props.linkLocation) neq 0>
									<div class="cswLinkButton #props.linkLocation#">
										#renderButtonCore(
											type=currButtonType,
											linkText=currLinkText,
											linkURL=currLinkURL,
											buttonStruct=currButtonStruct,
											linkStruct=currLinkStruct,
											buttonCorners=currButtonCorners,
											icon=currButtonIcon,
											linkAttrStruct=StructNew(),
											onClick=data.onClick,
											linkTarget=data.linkTarget
										)#
									</div>
								</cfif>
							
							<cfif len(data.slideText)>
								</div>
							</cfif>
						</div>
					</div>

					<!--- Render link/button --->
					<cfif currLinkURL neq ''
							AND currLinkText neq ''
							AND (FindNoCase('underslide', props.linkLocation) neq 0
							OR FindNoCase('middle', props.linkLocation) neq 0 )>
						<div class="cswLinkButton #props.linkLocation#">
							#renderButtonCore(
								type=currButtonType,
								linkText=currLinkText,
								linkURL=currLinkURL,
								buttonStruct=currButtonStruct,
								linkStruct=currLinkStruct,
								buttonCorners=currButtonCorners,
								icon=currButtonIcon,
								linkAttrStruct=StructNew())#
						</div>
					</cfif>
				</section>
			</div>
		</cfoutput>

	</cffunction>

</cfcomponent>